# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->
## [v0.2.1](https://github.com-personal/rohitgarud/llm-schema-lite/releases/tag/v0.2.1) - 2025-10-14

<small>[Compare with v0.2.0](https://github.com-personal/rohitgarud/llm-schema-lite/compare/v0.2.0...v0.2.1)</small>

### Docs

- update CHANGELOG for v0.2.0 ([c504369](https://github.com-personal/rohitgarud/llm-schema-lite/commit/c50436906db08107c3a26e0dafea1e83af62fd8d) by github-actions[bot]).

## [v0.2.0](https://github.com/rohitgarud/llm-schema-lite/releases/tag/v0.2.0) - 2025-10-14

<small>[Compare with v0.1.0](https://github.com/rohitgarud/llm-schema-lite/compare/v0.1.0...v0.2.0)</small>

### Features

- implement core llm-schema-lite with multi-format support ([849e87f](https://github.com/rohitgarud/llm-schema-lite/commit/849e87f33d39f941579a550eab963ac00cf02aaf) by Rohit Garud).

### Bug Fixes

- remove manual v0.2.0 entry to allow auto-generation ([172a2cc](https://github.com/rohitgarud/llm-schema-lite/commit/172a2ccc32d027ae6629d34f904f72f59c3511ee) by Rohit Garud).
- fix email-validator dependecy issue ([99251db](https://github.com/rohitgarud/llm-schema-lite/commit/99251db68c4af4217b8e3ed0010ff890e8fbfc72) by Rohit Garud).
- dynamic version issue in pyproject.toml ([40afd5e](https://github.com/rohitgarud/llm-schema-lite/commit/40afd5ec03eb16c8e95131e75b5887396864344b) by Rohit Garud).

### Docs

- Update readme and changelog ([a4696cb](https://github.com/rohitgarud/llm-schema-lite/commit/a4696cb58c99c8888cd0cdaadec5102869119332) by Rohit Garud).

### Chore

- add examples and update dependencies ([ffde05b](https://github.com/rohitgarud/llm-schema-lite/commit/ffde05b22c8b7a786a98c0dcb01125039ce80df1) by Rohit Garud).
- remove static versioning from pyproject.toml ([6fced87](https://github.com/rohitgarud/llm-schema-lite/commit/6fced872ffc1126527ff99e847cd582a490d95d9) by Rohit Garud).
- rename to llm-schema-lite ([914da1f](https://github.com/rohitgarud/llm-schema-lite/commit/914da1fca8873731302453b5eeaafcacc7b23749) by Rohit Garud).

### Tests

- add comprehensive test suite with 112 tests ([ea4f608](https://github.com/rohitgarud/llm-schema-lite/commit/ea4f60852bbe9bd917d68bb8bf5f3f3e9ce9fbad) by Rohit Garud).

## [v0.1.0](https://github.com/rohitgarud/llm-schema-lite/releases/tag/v0.1.0) - 2025-10-12

<small>[Compare with first commit](https://github.com/rohitgarud/llm-schema-lite/compare/51766385b3c7e7172bfae5e8e8c8b1b431ad0a24...v0.1.0)</small>

### Chore

- initial package structure ([17462ec](https://github.com/rohitgarud/llm-schema-lite/commit/17462ec0c8e135e202d58cf808ac732396ed8d58) by Rohit Garud).


## [Unreleased]

### Added
- Initial project structure
- Package configuration with uv support
- Pre-commit hooks for code quality
- Comprehensive development tooling
